@@ -1,6 +1,6 @@
 class EndPoints:
-    AUTH_URI = "https://connect.spotware.com/apps/auth"
-    TOKEN_URI = "https://connect.spotware.com/apps/token"
+    AUTH_URI = "https://openapi.ctrader.com/apps/auth"
+    TOKEN_URI = "https://openapi.ctrader.com/apps/token"
     PROTOBUF_DEMO_HOST = "demo.ctraderapi.com"
     PROTOBUF_LIVE_HOST = "live.ctraderapi.com"
     PROTOBUF_PORT = 5035
